<?php
/**
 * @package Joomla
 * @subpackage Abook
 * @copyright (C) 2010-now Federica Ugolotti
 * @license GNU/GPL, see LICENSE.php
 * Abook is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 3
 * as published by the Free Software Foundation.

 * Abook is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Abook; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
defined('_JEXEC') or die('Restricted access');
use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Uri\Uri;
use Joomla\Utilities\ArrayHelper;
use Joomla\CMS\Language\Multilanguage;
use Joomla\CMS\Language\Associations;
use Joomla\CMS\Layout\LayoutHelper;
use Joomla\CMS\Session\Session;

JHtml::addIncludePath(JPATH_COMPONENT . '/helpers/html');

$wa = $this->document->getWebAssetManager();
$wa->useScript('table.columns')
    ->useScript('multiselect');

$user   = Factory::getUser();
$userId         = $user->get('id');
$listOrder      = $this->state->get('list.ordering');
$listDirn       = $this->state->get('list.direction');
$archived       = $this->state->get('filter.published') == 2 ? true : false;
$trashed        = $this->state->get('filter.published') == -2 ? true : false;
$saveOrder      = $listOrder == 'a.ordering';
$canOrder       = $user->authorise('core.edit.state', 'com_abook.book');
$lend=0;

if ($saveOrder && !empty($this->items)) {
    $saveOrderingUrl = 'index.php?option=com_content&task=articles.saveOrderAjax&tmpl=component&' . Session::getFormToken() . '=1';
    HTMLHelper::_('draggablelist.draggable');
}

$sortFields = $this->getSortFields();
$assoc          = JLanguageAssociations::isEnabled();
?>
<form action="<?php echo JRoute::_('index.php?option=com_abook&view=books'); ?>" method="post" name="adminForm" id="adminForm">
  <div class="row">
    <div class="col-md-12">
        <div id="j-main-container" class="j-main-container">
		<?php
                // Search tools bar
                echo JLayoutHelper::render('joomla.searchtools.default', array('view' => $this));
                ?>
		<?php if (empty($this->items)) : ?>
			<div class="alert alert-info">
	                        <span class="icon-info-circle" aria-hidden="true"></span><span class="visually-hidden"><?php echo JText::_('INFO'); ?></span>
        	                <?php echo JText::_('JGLOBAL_NO_MATCHING_RESULTS'); ?>
                	</div>
                <?php else : ?>
		<div class="table-responsive">	
		<table class="table itemList" id="bookList">
                        <caption class="visually-hidden">
                            <?php echo JText::_('COM_ABOOK_BOOKS_TABLE_CAPTION'); ?>,
                            <span id="orderedBy"><?php echo JText::_('JGLOBAL_SORTED_BY'); ?> </span>,
                            <span id="filteredBy"><?php echo JText::_('JGLOBAL_FILTERED_BY'); ?></span>
                        </caption>
			<thead>
				<tr>
					<th class="w-1 text-center">
                                                <?php echo HTMLHelper::_('grid.checkall'); ?>
                                        </th>
					<th class="w-1 text-center d-none d-md-table-cell">
                                                <?php echo HTMLHelper::_('searchtools.sort', '', 'a.ordering', $listDirn, $listOrder, null, 'asc', 'JGRID_HEADING_ORDERING', 'icon-menu-2'); ?>
                                        </th>
					<th class="w-1 text-center">
                                                <?php echo HTMLHelper::_('searchtools.sort', 'JSTATUS', 'a.state', $listDirn, $listOrder); ?>
                                        </th>
					<th class="w-1 text-center">
						<?php echo JText::_( 'COM_ABOOK_COVER' ); ?>
					</th>			
					<th style="min-width:100px">
						<?php echo HTMLHelper::_('searchtools.sort',  'COM_ABOOK_TITLE', 'a.title', $listDirn, $listOrder );?>
					</th>
					<th class="w-5 d-none d-md-table-cell">
						<?php echo HTMLHelper::_('searchtools.sort',  'COM_ABOOK_EDITOR', 'a.ideditor', $listDirn, $listOrder );?>
		                        </th>
					<th class="w-3 d-none d-md-table-cell">
		                                <?php echo HTMLHelper::_('searchtools.sort',  'COM_ABOOK_YEAR', 'a.year', $listDirn, $listOrder );?>
                		        </th>
					<th class="w-5 d-none d-md-table-cell">
                		                <?php echo HTMLHelper::_('searchtools.sort',  'COM_ABOOK_LOCATION', 'a.idlocation', $listDirn, $listOrder );?>
		                        </th>
					<th class="w-5 d-none d-md-table-cell">
                                		<?php echo HTMLHelper::_('searchtools.sort',  'COM_ABOOK_LIBRARY', 'a.idlibrary', $listDirn, $listOrder );?>
		                        </th>
					<th class="w-5">
                                		<?php echo HTMLHelper::_('searchtools.sort',  'COM_ABOOK_CATEGORY', 'a.catid', $listDirn, $listOrder );?>
		                        </th>
					<th class="w-5">
						<?php echo HTMLHelper::_('searchtools.sort',  'COM_ABOOK_CATALOG', 'a.catalogo', $listDirn, $listOrder );?>
		                        </th>
					<th class="w-5 d-none d-md-table-cell">
						<?php echo HTMLHelper::_('searchtools.sort',  'COM_ABOOK_DATEINSERT', 'a.dateinsert', $listDirn, $listOrder );?>
		                        </th>
					<th class="w-3 d-none d-md-table-cell">
                                		<?php echo HTMLHelper::_('searchtools.sort',   'JGRID_HEADING_ACCESS', 'access_level', $listDirn, $listOrder ); ?>
		                        </th>
					<th class="w-3 d-none d-md-table-cell">
		                                <?php echo HTMLHelper::_('searchtools.sort', 'JGRID_HEADING_LANGUAGE', 'a.language', $listDirn, $listOrder); ?>
                		        </th>
					<th class="w-3 d-none d-lg-table-cell text-center">
						<?php echo HTMLHelper::_('searchtools.sort', 'JGLOBAL_HITS', 'a.hits', $listDirn, $listOrder); ?>
					</th>
					<th scope="col" class="w-3 d-none d-md-table-cell text-center">
                                        	<?php echo HTMLHelper::_('searchtools.sort', 'JGLOBAL_VOTES', 'rating_count', $listDirn, $listOrder); ?>
                                        </th>
                                        <th scope="col" class="w-3 d-none d-md-table-cell text-center">
                                                <?php echo HTMLHelper::_('searchtools.sort', 'JGLOBAL_RATINGS', 'rating', $listDirn, $listOrder); ?>
                                        </th>
					<?php if ($lend) :?>
					<th class="w-5">
                                		<?php echo HTMLHelper::_('searchtools.sort', 'COM_ABOOK_LEND', 'le.lend', $listDirn, $listOrder); ?>
                        		</th>
					<?php endif; ?>
					<th class="w-1 d-none d-md-table-cell">
                                                <?php echo HTMLHelper::_('searchtools.sort',  'JGRID_HEADING_ID', 'a.id', $listDirn, $listOrder );?>
                                        </th>
				</tr>
			</thead>
			<tbody<?php if ($saveOrder) :
                            ?> class="js-draggable" data-url="<?php echo $saveOrderingUrl; ?>" data-direction="<?php echo strtolower($listDirn); ?>" data-nested="true"<?php
                              endif; ?>>
			<?php
				foreach ($this->items as $i => $item) :
				$item->max_ordering = 0;
				//$ordering   = ($listOrder == 'a.ordering');
			        $canCreate  = $user->authorise('core.create', 'com_abook.category.'.$item->catid);
			        $canEdit    = $user->authorise('core.edit', 'com_abook.book.'.$item->id);
			        $canCheckin = $user->authorise('core.manage', 'com_checkin') || $item->checked_out==$userId || is_null($item->checked_out);
				$canEditOwn = $user->authorise('core.edit.own', 'com_abook.book.'.$item->id) && $item->user_id == $userId;
			        $canChange  = $user->authorise('core.edit.state', 'com_abook.book.'.$item->id) && $canCheckin;

				$link2		= JRoute::_( 'index.php?option=com_abook&task=editor.edit&cid[]='. $item->editorid );
				$link3          = JRoute::_( 'index.php?option=com_abook&task=category.edit&cid[]='. $item->catid );
			?>
				<tr class="row<?php echo $i % 2; ?>" data-draggable-group="<?php echo $item->catid; ?>">
                                        <td class="text-center">
                                                <?php echo HTMLHelper::_('grid.id', $i, $item->id, false, 'cid', 'cb', $item->title); ?>
                                        </td>
                                <td class="text-center d-none d-md-table-cell">
                                    <?php
                                    $iconClass = '';
                                    if (!$canChange) {
                                        $iconClass = ' inactive';
                                    } elseif (!$saveOrder) {
                                        $iconClass = ' inactive" title="' . JText::_('JORDERINGDISABLED');
                                    }
                                    ?>
                                    <span class="sortable-handler<?php echo $iconClass ?>">
                                        <span class="icon-ellipsis-v" aria-hidden="true"></span>
                                    </span>
                                    <?php if ($canChange && $saveOrder) : ?>
                                        <input type="text" name="order[]" size="5" value="<?php echo $item->ordering; ?>" class="width-20 text-area-order hidden">
                                    <?php endif; ?>
                                </td>
					<td class="text-center">
						<?php echo HTMLHelper::_('jgrid.published', $item->state, $i, 'books.', $canChange); ?>
                        		</td>
					<td class="text-center">
						<?php if ($item->image){
			                                $img = HTMLHelper::cleanImageURL($item->image);
							$extraAttr = "";
			                                // Set lazyloading only for images which have width and height attributes
			                                if ((isset($img->attributes['width']) && (int) $img->attributes['width'] > 0)
			                                && (isset($img->attributes['height']) && (int) $img->attributes['height'] > 0))
			                                {
			                                        $extraAttr = ArrayHelper::toString($img->attributes) . ' loading="lazy"';
			                                }
							$imgurl = JURI::root().$img->url;
						}else{
							$imgurl = JURI::root()."components/com_abook/assets/images/nocover.png";
							$extraAttr = ' width="80" height="112" loading="lazy" ';
						}
						?>
						<img class="img-polaroid" title="" src="<?php echo $imgurl;?>" <?php echo $extraAttr;?>  alt="<?php echo $item->title;?>" style="max-width: 80px;height: auto;" >
						
					</td>
					<th class="has-context">
                        			<?php if ($item->checked_out) : ?>
			                        	<?php echo HTMLHelper::_('jgrid.checkedout', $i, $item->owner, $item->checked_out_time, 'books.', $canCheckin); ?>
                        			<?php endif; ?>
                        			<?php if ($canEdit || $canEditOwn) : ?>
                        				<a href="<?php echo JRoute::_('index.php?option=com_abook&view=book&task=book.edit&id='.$item->id);?>" title="<?php echo JText::_('JACTION_EDIT'); ?>"><?php echo $this->escape($item->title); ?></a>
                        			<?php else : ?>
                                			<span><?php echo $this->escape($item->title); ?></span>
                        			<?php endif; ?>
						<p class="small"><?php echo JText::sprintf('JGLOBAL_LIST_ALIAS', $this->escape($item->alias));?></p>
						<p class="small"><?php echo JText::_( 'COM_ABOOK_AUTHOR' ); ?>: <?php echo $item->author; ?></p>
						<?php if ($item->note!=""){ ?>
                                                        <p class="small"><span class="tbody-icon"><i class="icon-info text-dark"></i> <?php echo JText::_( 'COM_ABOOK_NOTE' );?>: <?php echo $item->note;?></span></p>
                                                <?php } ?>
                        		</th>
					<td class="d-none d-md-table-cell">
		                                <a href="<?php echo $link2; ?>" title="<?php echo JText::_( 'JACTION_EDIT' );?>::<?php echo $item->editor; ?>"><?php echo $item->editor; ?></a>
                		        </td>
					<td class="d-none d-md-table-cell">
                		                <?php echo $item->year; ?>
		                        </td>
					<td class="d-none d-md-table-cell">
                                		<?php echo $item->location; ?>
		                        </td>
					<td class="d-none d-md-table-cell">
                                		<?php echo $item->library; ?>
		                        </td>
					<td>
		                                <a href="<?php echo $link3; ?>" title="<?php echo JText::_( 'JACTION_EDIT' );?>::<?php echo $item->category; ?>"><?php echo $item->category; ?></a>
                		        </td>
					<td class="small">
                		                <?php echo $item->catalogo; ?>
		                        </td>
					<td class="small d-none d-md-table-cell">
						<div class="text-nowrap"><?php echo JHTML::_('date', $item->dateinsert, 'd-m-Y H:i') ?></div>
                		        </td>
					<td class="small d-none d-md-table-cell">
                                		<?php echo $this->escape($item->access_level); ?>
		                        </td>
					<td class="text-center d-none d-md-table-cell">
						<?php if (Multilanguage::isEnabled()) : ?>
							<?php echo LayoutHelper::render('joomla.content.language', $item); ?>
						<?php else: ?>
	                                		<?php if ($item->language=='*'):?>
			                                        <?php echo JText::_('JALL'); ?>
                			                <?php else:?>
                        	        			<?php echo $item->language_title ? $this->escape($item->language_title) : JText::_('JUNDEFINED'); ?>
		                	         	<?php endif;?>
						<?php endif; ?>
                		         </td>
					<td class="d-none d-lg-table-cell text-center">
						<span class="badge bg-info">
                                                	<?php echo (int) $item->hits; ?>
						</span>
					</td>
					<td class="d-none d-md-table-cell text-center">
                                                <span class="badge bg-success">
                                	                <?php echo (int) $item->rating_count; ?>
                        	                </span>
                                        </td>
                                        <td class="d-none d-md-table-cell text-center">
                                                <span class="badge bg-warning text-dark">
                 	                               <?php echo (int) $item->rating; ?>
       		                                </span>
                                        </td>
					<?php if ($lend):?>
					<td class="text-center">
		                                <?php 
							if ($item->lend_id){ ?>
							<a href="<?php echo JRoute::_('index.php?option=com_abook&view=lend&task=lend.edit&id='.$item->lend_id);?>"><?php echo JHtml::_("image", "administrator/components/com_abook/assets/images/arrow-red.png", JText::_('JACTION_EDIT'));?></a>
						<?php	}	?>
                        		</td>
					<?php endif; ?>
					<td class="text-end d-none d-md-table-cell">
                                                <?php echo $item->id; ?>
                                        </td>
				</tr>
				<?php endforeach;?>
			</tbody>
		</table>
		</div>
		<?php endif; ?>
		<?php echo $this->pagination->getListFooter(); ?>
		<input type="hidden" name="task" value="" />
		<input type="hidden" name="boxchecked" value="0" />
		<?php echo HTMLHelper::_('form.token'); ?>
	</div>
    </div>
  </div>
</form>
<p><?php echo JHTML::_('credit.credit');?></p>
