<?php
/**
 * @package Joomla
 * @subpackage Abook
 * @copyright (C) 2010-now Federica Ugolotti
 * @license GNU/GPL, see LICENSE.php
 * Abook is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 3
 * as published by the Free Software Foundation.

 * Abook is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Abook; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
defined('_JEXEC') or die('Restricted access'); 
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\Utilities\ArrayHelper;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Plugin\PluginHelper;
use Joomla\CMS\Factory;

JHtml::addIncludePath(JPATH_COMPONENT.DIRECTORY_SEPARATOR.'helpers');
HTMLHelper::_('bootstrap.dropdown');
$pageClass = $this->params->get('pageclass_sfx');
$htag    = $this->params->get('show_page_heading') ? 'h2' : 'h1';
?>
<div class="item-page<?php echo $this->escape($pageClass); ?>" itemscope itemtype="http://schema.org/Book">
	<?php if ($this->params->def('show_page_heading', 1)) : ?>
		<div class="page-header">
			<h1><?php echo $this->params->get( 'page_heading');?></h1>
		</div>
	<?php endif; ?>
	<?php if ($this->params->get( 'search', 1 )== 1 && !$this->print) { ?>
                <?php echo JHTML::_('icon.search');?>
                <div class="clr"></div>
        <?php } ?>
        <?php if ($this->params->get( 'breadcrumb', 1 )== 2 && !$this->print) { ?>
                <div class="abook-path">
                        <?php echo JHTML::_('icon.breadcrumb', $this->path);?>
                </div>
        <div class="clearfix"></div>
        <?php } ?>
	<?php if (!$this->print) : ?>
		<?php if ($this->params->get('show_print_icon') || $this->params->get('show_email_icon')) : ?>
        		<div class="dropdown float-end">
				<button class="btn btn-secondary dropdown-toggle" type="button" id="dropdownMenuButton1" data-bs-toggle="dropdown" aria-expanded="false"><span class="icon-cog"></span> <span class="caret"></span></button>
				<ul class="dropdown-menu">
        	        		<?php if ($this->params->get('show_print_icon')) : ?>
		                        <li class="print-icon">
        		                <?php echo JHtml::_('icon.print_popup',  $this->item, $this->params); ?>
                		        </li>
                			<?php endif; ?>
                			<?php if ($this->params->get('show_email_icon')) : ?>
	                        	<li class="email-icon">
		                        <?php echo JHtml::_('icon.email',  $this->item, $this->params); ?>
        		                </li>
                			<?php endif; ?>
        			</ul>
			</div>
		<?php endif; ?>
	<?php else : ?>
		<div id="pop-print" class="text-end d-print-none">
                                <?php echo JHtml::_('icon.print_screen', $this->item, $this->params); ?>
                        </div>
	<?php endif; ?>
	<div class="page-header">
	<<?php echo $htag; ?> itemprop="name"><?php echo $this->item->title;?>
	<p><small><?php echo $this->item->subtitle;?></small></p>
	</<?php echo $htag; ?>>
	</div>
	<?php echo $this->item->event->afterDisplayTitle; ?>
	<?php echo $this->item->event->beforeDisplayContent; ?>
	<div class="row">
	<?php if ($this->params->get('show_bookcover', 1) && $this->params->get('bookcover_position', 'left')=='left'){     ?>
		<?php if ($this->item->other_info!=''){?>
                <div class="span3 col-md-3">
		<?php }else { ?>
                <div class="span4 col-md-4">
		<?php } ?>
                        <div class="img-intro-left cover">
                        <?php if ($this->item->image){
				$extraAttr = "";
				$img = HTMLHelper::cleanImageURL($this->item->image);
				// Set lazyloading only for images which have width and height attributes
				if ((isset($img->attributes['width']) && (int) $img->attributes['width'] > 0)
				&& (isset($img->attributes['height']) && (int) $img->attributes['height'] > 0))
				{
				        $extraAttr = ArrayHelper::toString($img->attributes) . ' loading="lazy"';
				}
                                if ($this->params->get('show_bookcover_link', 0) && $this->item->file!=''){
                                        echo '<a href="images/'.$this->params->get('file_path').'/'.$this->item->file.'" 
                                        title="'.JText::_('COM_ABOOK_COVEROF').' '.$this->item->title.'" target="_blank">
                                        <img itemprop="image" class="img-polaroid" src="'.$img->url.'" alt="'.JText::_('COM_ABOOK_COVEROF').' '.$this->item->title.'" '.$extraAttr.'/>
                                        </a>';
                                }else{
                                        echo '<img itemprop="image" class="img-polaroid" src="'.$img->url.'" alt="'.JText::_('COM_ABOOK_COVEROF').' '.$this->item->title.'" '.$extraAttr.'/>';
                                }
                        }elseif($this->item->file!=''){
				echo '<a href="images/'.$this->params->get('file_path').'/'.$this->item->file.'" 
                                title="'.JText::_('COM_ABOOK_COVEROF').' '.$this->item->title.'" target="_blank">
                                <img class="img-polaroid" src="components/com_abook/assets/images/nocover.png" alt="'.JText::_('COM_ABOOK_NOCOVEROF').'" />
				</a>';
                        }else{
				echo '<img class="img-polaroid" src="components/com_abook/assets/images/nocover.png" alt="'.JText::_('COM_ABOOK_NOCOVEROF').'" />';
			}
                        ?>
                        </div>
                </div>
        <?php }?>
		<?php if ($this->item->other_info!=''){?>
                <div class="span6 col">
                <?php }else{?>
		<div class="span8 col">
		<?php }?>
			<dl class="bookdetails">
				<?php if ($this->params->get('show_category', 1)){ ?>
				<dd>
					<span class="icon-folder-open icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_CATEGORY');?>: </strong>
					<a href="<?php echo AbookHelperRoute::getCategoryRoute($this->item->catslug);?>"><?php echo $this->item->category_title;?></a>
				</dd>
				<?php } ?>
				<?php
                                $a=count($this->authors);
                                if ($a > 0 && $this->params->get('show_author', 1)){?>
				<dd itemtype="http://schema.org/Person" itemscope itemprop="author">
					<span class="icon-user icon-fw"></span> <strong><?php echo $this->item->editedby==1 ? JText::_('COM_ABOOK_EDITED_BY')." " : JText::_('COM_ABOOK_AUTHOR');?>: </strong>
					<?php
                        		$n=count($this->authors);
                        		$k=0;
                        		foreach ($this->authors as $author){
                                		$k=$k +1;
						$link = AbookHelperRoute::getAuthorRoute(!empty($author->alias) ? ($author->author_id.':'.$author->alias) : $author->author_id);
                                		echo '<a itemprop="url" href="' .$link .'"><span itemprop="name">' .$author->author_name .'</span></a>';
                                		if ($n != $k) echo ", ";
                        		}
                        		?>
				</dd>
				<?php } ?>
				<?php if ($this->item->editor_name!='' && $this->params->get('show_editor', 1)){ ?>
			        <dd itemtype="http://schema.org/Organization" itemscope itemprop="publisher">
                			<span class="icon-briefcase icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_EDITOR');?>: </strong><span itemprop="name"><?php echo $this->item->editor_name;?></span>
			        </dd>
				<?php } ?>
			        <?php if ($this->item->pag>0 && $this->params->get('show_pag', 1)){ ?>
			        <dd>
			                <span class="icon-book icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_PAGES');?>: </strong><span itemprop="numberOfPages"><?php echo $this->item->pag;?></span>
			        </dd>
			        <?php } ?>
			        <?php if ($this->item->price!=''){ ?>
			        <dd itemprop="offers" itemscope itemtype="http://schema.org/Offer">
			                <span class="icon-cart icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_PRICE');?>: </strong><span itemprop="price"><?php echo $this->item->price;?></span>
			        </dd>
			        <?php } ?>
				<?php if ($this->item->lang!='' && $this->params->get('show_lang', 1)){ ?>
                                <dd>
                                        <span class="fas fa-language icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_LANG');?>: </strong><span itemprop="inLanguage"><?php echo $this->item->lang;?></span>
                                </dd>
                                <?php } ?>
			        <?php if ($this->item->isbn!='' && $this->params->get('show_isbn', 1)){ ?>
			        <dd>
			                <span class="fas fa-hashtag icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_ISBN');?>: </strong><span itemprop="isbn"><?php echo $this->item->isbn;?></span>
			        </dd>
			        <?php } ?>
				<?php if ($this->item->issn!='' && $this->params->get('show_issn', 1)){ ?>
                                <dd>
                                        <span class="fas fa-hashtag icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_ISSN');?>: </strong><span><?php echo $this->item->issn;?></span>
                                </dd>
                                <?php } ?>
				<?php if ($this->item->doi!='' && $this->params->get('show_doi', 1)){ ?>
                                <dd>
                                        <span class="icon-bookmark icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_DOI');?>: </strong><span><?php echo $this->item->doi;?></span>
                                </dd>
                                <?php } ?>
				<?php if ($this->item->numpublication!=0 && $this->params->get('show_numpublication', 1)){ ?>
                                <dd>
                                        <span class="fas fa-hashtag icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_NUMPUBLICATION');?>: </strong><span><?php echo $this->item->numpublication;?></span>
                                </dd>
                                <?php } ?>
			        <?php if ($this->item->library_name!='' && $this->params->get('show_library', 1)){ ?>
			        <dd>
			                <span class="icon-home icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_LIBRARY');?>: </strong><?php echo $this->item->library_name;?>
			        </dd>
			        <?php } ?>
				<?php if ($this->item->location_name!='' && $this->params->get('show_location', 1)){ ?>
                                <dd>
                                        <span class="icon-flag icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_LOCATION');?>: </strong><span itemprop="contentLocation"><?php echo $this->item->location_name;?></span>
                                </dd>
                                <?php } ?>
			        <?php if ($this->item->year > 0 && $this->params->get('show_year', 1)){ ?>
			        <dd>
			                <span class="icon-calendar icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_YEAR');?>: </strong><span itemprop="copyrightYear"><?php echo $this->item->year;?></span>
			        </dd>
			        <?php } ?>
				<?php if ($this->item->catalogo!="" && $this->params->get('show_catalog', 1)){ ?>
                                <dd>
                                        <span class="fas fa-hashtag icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_CATALOG');?>: </strong><?php echo $this->item->catalogo;?>
                                </dd>
                                <?php } ?>
				<?php if ($this->item->file!="" && in_array($this->params->get('allow_download'), $this->user->getAuthorisedViewLevels())){ ?>
                                <dd>
                                        <span class="icon-file icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_FILE');?>: </strong>
						<a href="images/<?php echo $this->params->get('file_path').'/'.$this->item->file;?>" target="_blank"><?php echo $this->filename; ?></a>
                                </dd>
                                <?php } ?>
			        <?php if ($this->params->get('linkto')==1){
					$file_url_path = "components/com_abook/assets/images/link/";
					$file1= $this->params->get('linkimage'); 
					if ($this->item->url!=''){?>
			        <dd>
			                <span class="icon-link icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_LINK');?>: </strong> <a href="<?php echo $this->item->url;?>" target="_blank"><img src="<?php echo Juri::base(true).$file_url_path.$file1;?>" alt="<?php echo JText::_('COM_ABOOK_LINK');?>" /> <?php echo $this->item->url_label;?></a>
			        </dd>
					<?php }
					if ($this->item->url2!=''){
					$name = JFile::stripExt($file1);
					$ext =  JFile::getExt($file1);
					$new_file= JFile::exists(JPATH_BASE.'/'.$file_url_path.$name.'-2.'.$ext)?$file_url_path.$name.'-2.'.$ext : $file_url_path.$file1;
					?>
				<dd>
                                        <span class="icon-link icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_LINK');?>: </strong> <a href="<?php echo $this->item->url2;?>" target="_blank"><img src="<?php echo Juri::base(true).$new_file;?>" alt="<?php echo JText::_('COM_ABOOK_LINK');?>" /> <?php echo $this->item->url2_label;?></a>
                                </dd>
					<?php }
					if ($this->item->url3!=''){
					$name = JFile::stripExt($file1);
					$ext =  JFile::getExt($file1);
					$new_file= JFile::exists(JPATH_BASE.'/'.$file_url_path.$name.'-3.'.$ext)?$file_url_path.$name.'-3.'.$ext : $file_url_path.$file1;
					?>
                                <dd>
                                        <span class="icon-link icon-fw"></span> <strong><?php echo JText::_('COM_ABOOK_LINK');?>: </strong> <a href="<?php echo $this->item->url3;?>" target="_blank"><img src="<?php echo Juri::base(true).$new_file;?>" alt="<?php echo JText::_('COM_ABOOK_LINK');?>" /> <?php echo $this->item->url3_label;?></a>
                                </dd>
                                        <?php }?>
			        <?php } ?>
				<?php if ($this->item->note!='' && $this->params->get('show_note', 0)==1){ ?>
                                <dd>
                                        <strong><span class="icon-info icon-fw"></span> <?php echo JText::_('COM_ABOOK_NOTE');?>: </strong><?php echo $this->item->note;?>
                                </dd>
                                <?php } ?>
			</dl>
		</div>
		<?php if ($this->item->other_info!=''){?>
		<div class="span3 col-md-3">
			<?php echo $this->item->other_info;?>
		</div>
		<?php } ?>
		<?php if ($this->params->get('show_bookcover', 1) && $this->params->get('bookcover_position', 'left')=='right'){     ?>
		<?php if ($this->item->other_info!=''){?>
                <div class="span3 col-md-3">
		<?php }else{?>
                <div class="span4 col-md-4">
		<?php }?>
                        <div class="img-intro-right cover">
                        <?php if ($this->item->image){
                                if ($this->params->get('show_bookcover_link', 0) && $this->item->file!=''){
                                        echo '<a href="images/'.$this->params->get('file_path').'/'.$this->item->file.'" 
                                        title="'.JText::_('COM_ABOOK_COVEROF').' '.$this->item->title.'" target="_blank">
                                        <img itemprop="image" class="img-polaroid" src="'.$this->item->image.'" alt="'.JText::_('COM_ABOOK_COVEROF').' '.$this->item->title.'" />
                                        </a>';
                                }else{
                                        echo '<a href="'.$this->item->image.'" 
                                        style="cursor: pointer;" class="modal" title="'.JText::_('COM_ABOOK_COVEROF').' '.$this->item->title.'">
                                        <img itemprop="image" class="img-polaroid" src="'.$this->item->image.'" alt="'.JText::_('COM_ABOOK_COVEROF').' '.$this->item->title.'" />
                                        </a>';
                                }
                        }elseif($this->item->file!=''){
                                echo '<a href="images/'.$this->params->get('file_path').'/'.$this->item->file.'" 
                                title="'.JText::_('COM_ABOOK_COVEROF').' '.$this->item->title.'" target="_blank">
                                <img class="img-polaroid" src="components/com_abook/assets/images/nocover.png" alt="'.JText::_('COM_ABOOK_NOCOVEROF').'" />
                                </a>';
                        }else{
                                echo '<img class="img-polaroid" src="components/com_abook/assets/images/nocover.png" alt="'.JText::_('COM_ABOOK_NOCOVEROF').'" />';
                        }
                        ?>
                        </div>
                </div>
        <?php }?>
	</div>
	<?php if(($this->params->get('show_hits', 1)==1) || ($this->params->get('view_rate', 1)==1) || ($this->params->get('show_lend_request', 1)==1) || ($this->params->get('show_lend_availability', 1)==1)){ ?>
	<div class="row">
		<div class="span4 col-md-4 muted">
			<?php if ($this->params->get( 'show_hits', 1 )==1){ ?>
				<p>
				<span class="icon-eye-open"></span> <strong><?php echo JText::_('COM_ABOOK_HITS');?>: </strong>
				<meta itemprop="interactionCount" content="UserPageVisits:<?php echo $this->item->hits;?>"/><?php echo $this->item->hits;?>
				</p>
			<?php } ?>
			<?php
			$lendstate=isset($this->lend->state)?$this->lend->state:1;
			if ($this->params->get( 'show_lend_availability', 1 )==1) {
	                        switch($lendstate){
        	                        case 0:
                	                        $state="bg-danger";
                        	                $state_label=JText::_('COM_ABOOK_LEND_LENT');
                                	        break;
					default:
	                                case 1:
        	                                $state="bg-success";
                	                        $state_label=JText::_('COM_ABOOK_LEND_AVAILABLE');
                        	                break;
                                	case 2:
                                        	$state="bg-warning";
	                                        $state_label=JText::_('COM_ABOOK_LEND_REQUESTED');
        	                                break;
                	        }
				?>
				<p>
				<span class="icon-share-alt"></span>  <strong><?php echo JText::_('COM_ABOOK_LENT_STATUS');?></strong><span class="badge <?php echo $state;?>"><?php echo $state_label;?></span>
				</p>
				<p>
				<div><strong><?php echo JText::_('COM_ABOOK_LEND_AVAILABILITY');?>: </strong><?php echo $this->item->qty - (isset($this->lend->lent)?$this->lend->lent:0) - (isset($this->lend->requested)?$this->lend->requested:0);?>/<?php echo $this->item->qty;?></div>
				</p>
                	<?php }?>
		</div>
		<div class="span5 col-md-5">
			<?php if ($this->params->get( 'view_rate', 1 )==1) { ?>
				<?php echo JHTML::_('icon.votebook', $this->item, $this->vote);?>	
			<?php } ?>
		</div>
		<?php if (!$this->print && ($this->params->get( 'show_lend_request', 1 )==1 && in_array($this->params->get('allow_lend_request'), $this->user->getAuthorisedViewLevels()) && $lendstate == 1)) {?>
		<div class="span3 col-md-3">
			<button type="button" class="btn btn-primary" data-bs-toggle="collapse" data-bs-target="#collapseRequest">
				<?php echo JText::_( 'COM_ABOOK_LEND_REQUEST' );?> <span class="icon-arrow-right"></span>
			</button>
		</div>
		<?php }?>
	</div>
	<?php if ($this->params->get( 'show_lend_request', 1 )==1 && in_array($this->params->get('allow_lend_request'), $this->user->getAuthorisedViewLevels())) {
        	$uri = Uri::getInstance();
                $uri->setQuery($uri->getQuery().'&hitcount=0');
        ?>
	<div id="collapseRequest" class="row bg-secondary bg-opacity-10 collapse">
		<div class="col-md-4 m-5">
        	<form action="<?php echo $uri->toString();?>" method="post" class="form-horizontal" name="requestForm" id="requestForm">
			<legend><?php echo JText::_( 'COM_ABOOK_LEND_REQUEST_FORM' );?></legend>
			<?php if ($this->user->guest){?>
				<div class="mb-3">
                                	<label class="form-label" for="custom_user_name"><?php echo JText::_( 'COM_ABOOK_CUSTOM_USERNAME' );?></label>
	                                <input class="form-control" type="text" name="custom_user_name" value="" />
				</div>
				<div class="mb-3">
					<label class="form-label" for="custom_user_email"><?php echo JText::_( 'COM_ABOOK_CUSTOM_USEREMAIL' );?></label>
                                	<input class="form-control" type="text" name="custom_user_email" value="" />
				</div>
			<?php }else{?>
				<div class="mb-3">
                                        <label class="form-label" for="custom_user_name"><?php echo JText::_( 'COM_ABOOK_CUSTOM_USERNAME' );?></label>
                                        <div class="form-control"><?php echo $this->user->name;?></div>
                                </div>
                                <div class="mb-3">
                                        <label class="form-label" for="custom_user_email"><?php echo JText::_( 'COM_ABOOK_CUSTOM_USEREMAIL' );?></label>
                                        <div class="form-control"><?php echo $this->user->email;?></div>
                                </div>
			<?php }?>
			<div class="mb-3">
				<label class="form-label" for="lend_out"><?php echo JText::_( 'COM_ABOOK_LEND_OUT' );?></label>
        	                <?php echo JHtml::_("calendar", JHtml::_("date", 'now', 'Y-m-d'), "lend_out", "lend_out",'%Y-%m-%d');?>
			</div>
			<div class="mb-3">
				<label class="form-label" for="lend_in"><?php echo JText::_( 'COM_ABOOK_LEND_IN' );?></label>
        	                <?php echo JHtml::_("calendar", JHtml::_("date", 'now', 'Y-m-d'), "lend_in", "lend_in", '%Y-%m-%d');?>
			</div>
			<?php
			$captcha=$this->params->get('captcha', JFactory::getConfig()->get('captcha'));
			$isEnabled=PluginHelper::isEnabled('captcha', $captcha);
			$campo[0]='';
			if ($captcha!="0" && !$isEnabled){
				$campo[0]=JText::sprintf("COM_ABOOK_ENABLE_CAPTCHA", $captcha);
			}elseif ($this->user->guest){
				if ($captcha!="0"){
					PluginHelper::importPlugin('captcha', $captcha);
					Factory::getApplication()->triggerEvent('onInit');
					$campo=Factory::getApplication()->triggerEvent('onDisplay');?>
					<div class="control-group">
        		                        <div class="control-label"><label for="jform_captcha"><?php echo JText::_( 'COM_ABOOK_CAPTCHA_LABEL' );?></label></div>
						<div class="controls"><?php echo $campo[0];?></div>
					</div>
				<?php }
			}?>
			<div class="mb-3">
		        	<input class="btn btn-primary" type="submit" name="submit_vote" value="<?php echo JText::_( 'COM_ABOOK_LEND_SEND_REQUEST' );?>" />
			</div>
                        <input type="hidden" name="task" value="book.lendrequest" />
			<input type="hidden" name="url" value="<?php echo $uri->toString();?>" />
			<?php echo JHtml::_('form.token'); ?>
                </form>
		</div>
	</div>
        <?php }?>
	<?php } ?>
	<?php if ($this->item->description!='' && $this->params->get('show_description', 1)){ ?>
	<div class="row">
                <div class="span12">
			<?php if ($this->item->authorreview!= '' && $this->params->get('show_writtenby')){?>
			<div class="description" itemprop="review" itemscope itemtype="http://schema.org/Review">
			<?php }else{?>
			<div class="description" itemprop="description">
			<?php }?>
				<?php if ($this->params->get('show_description_title', 1)){ ?>
				<div>
					<h3><?php echo JText::_('COM_ABOOK_REVIEW');?></h3>
				</div>
				<?php }?>
				<?php if ($this->item->authorreview!= '' && $this->params->get('show_writtenby')){?>
					<div class="muted createdby"><?php JText::printf( 'COM_ABOOK_WRITTEN_BY', '<span itemprop="reviewBody">'.$this->item->authorreview.'</span>'); ?></div>
					<span itemprop="reviewBody"><?php echo $this->item->description;?></span>
				<?php }else{?>
					<?php echo $this->item->description;?>
				<?php }?>
			</div> 
		</div>
	</div>
	<?php } ?>
	<?php if ($this->item->file!='' && Jfile::getExt(JPATH_BASE . '/images/' . $this->params->get('file_path') . '/' . $this->item->file) == 'pdf' && $this->params->get('display_pdf', 1)){ ?>
		<embed src="images/<?php echo $this->params->get('file_path').'/'.$this->item->file;?>" width="100%" height="500" />
	<?php } ?>
	<?php echo $this->item->event->afterDisplayContent; ?>
	<div class="clr"></div>
	<?php if ($this->params->get('show_tags', 1) && !empty($this->tags)) : ?>
		<?php $this->item->tagLayout = new JLayoutFile('book.tags'); ?>
        	<div class="row mb-2">
                	<div class="span12 col-12"><?php echo $this->item->tagLayout->render($this->tags); ?></div>
		</div>
        <?php endif; ?>
		<?php if (isset($this->item->docsfolder) && $this->item->docsfolder && $this->params->get('show_docs', 0)){
                $t=count($this->docslist);
                ?>
                <h6><?php echo JText::_('COM_ABOOK_DOCUMENTS_DESC');?></h6>
                <div id="documents">
                        <ul class="col1">
                        <?php for($i=0; $i<($t / 2); $i++){?>
                                <li><a href="<?php echo $this->item->docsfolder.'/'.$this->docslist[$i];?>"><?php echo JFile::stripExt($this->docslist[$i]);?></a></li>
                        <?php }?>
                        </ul>
                        <ul class="col2">
                        <?php for($i=($t / 2); $i<$t; $i++){?>
                        <li><a href="<?php echo $this->item->docsfolder.'/'.$this->docslist[$i];?>"><?php echo JFile::stripExt($this->docslist[$i]);?></a></li>
                        <?php }?>
                        </ul>
                        <div class="clr"></div>
                </div>
                <?php }?>
	<div class="row muted createdate">
			<div class="span8 col-md-8">
				<?php
					if($this->params->get( 'view_date' )==1){?>
					<span class="icon-calendar icon-fw"></span>
					<?php echo JText::_('COM_ABOOK_DATE_INSERT');?>: <span itemprop="datePublished"><?php echo JHTML::_('date', $this->item->dateinsert, JText::_('DATE_FORMAT_LC1')) ?></span>
				<?php } ?>
			</div>
			<div class="span4 col-md-4">
				<?php echo JHtml::_('we.we') ?>
			</div>
	</div>
	<?php
		if ($a > 0 && $this->params->get('show_author_bio', 0)){?>
			<div class="authorbio">
			<h3><?php echo JText::_('COM_ABOOK_AUTHOR_THIS-BOOK');?></h3>
			<?php foreach ($this->authors as $author){?>
			<div class="bio">
				<h4><?php echo $author->author_name;?></h4>
				<div class="row">
					<?php if($author->image!=''){?>
					<div class="span2"><img src="<?php echo $author->image;?>" alt="<?php echo $author->author_name;?>" /></div>
					<div class="span10"><?php echo $author->description;?></div>
					<?php }else{?>
					<div class="span12"><?php echo $author->description;?></div>
					<?php }?>
				</div>
			</div>
			<?php }?>
			</div>
		<?php }
	?>
	<div class="clr"></div>
	<?php if ($this->params->get( 'display_book_comments',1 ) == 1) {
                $jcomments_plugin=JFile::exists(JPATH_BASE.DIRECTORY_SEPARATOR.'components'.DIRECTORY_SEPARATOR.'com_jcomments'.DIRECTORY_SEPARATOR.'jcomments.php');
                if ($jcomments_plugin) {
                	include_once(JPATH_BASE.DIRECTORY_SEPARATOR.'components'.DIRECTORY_SEPARATOR.'com_jcomments'.DIRECTORY_SEPARATOR.'jcomments.php');
                        echo '<br />'.JComments::show($this->item->id, 'com_abook', JText::_('COM_ABOOK_CATEGORY') .' '. $this->item->title);
                }
        }?>
</div>
<div class="clr"></div>
